@@ -22,7 +22,6 @@ THE SOFTWARE.
 package macho
 
 import (
-	"bytes"
 	"crypto/ecdsa"
 	"crypto/rsa"
 	"encoding/json"
@@ -34,7 +33,6 @@ import (
 	"path/filepath"
 	"strings"
 	"text/tabwriter"
-	"unicode"
 
 	"github.com/AlecAivazis/survey/v2"
 	"github.com/alecthomas/chroma/v2/quick"
@@ -984,45 +982,12 @@ var machoInfoCmd = &cobra.Command{
 				fmt.Println("STRINGS")
 				fmt.Println("=======")
 			}
-			// TODO: add option to dump all strings - https://github.com/robpike/strings/blob/master/strings.go
-			for _, sec := range m.Sections {
-				if sec.Flags.IsCstringLiterals() || sec.Name == "__os_log" || (sec.Seg == "__TEXT" && sec.Name == "__const") {
-					off, err := m.GetOffset(sec.Addr)
-					if err != nil {
-						return fmt.Errorf("failed to get offset for %s.%s: %v", sec.Seg, sec.Name, err)
-					}
-					dat := make([]byte, sec.Size)
-					if _, err = m.ReadAt(dat, int64(off)); err != nil {
-						return fmt.Errorf("failed to read cstring data in %s.%s: %v", sec.Seg, sec.Name, err)
-					}
-
-					fmt.Printf("\n[%s.%s]\n", sec.Seg, sec.Name)
-
-					csr := bytes.NewBuffer(dat)
-
-					for {
-						pos := sec.Addr + uint64(csr.Cap()-csr.Len())
-
-						s, err := csr.ReadString('\x00')
-						if err != nil {
-							if err == io.EOF {
-								break
-							}
-							return fmt.Errorf("failed to read string: %v", err)
-						}
-
-						s = strings.Trim(s, "\x00")
-
-						if len(s) > 0 {
-							for _, r := range s {
-								if r > unicode.MaxASCII || !unicode.IsPrint(r) {
-									continue // skip non-ascii strings
-								}
-							}
-							fmt.Printf("%s: %s\n", symAddrColor("%#09x", pos), symNameColor(fmt.Sprintf("%#v", s)))
-						}
-					}
-				}
+			strs, err := mcmd.GetStrings(m)
+			if err != nil {
+				return fmt.Errorf("failed to get strings: %v", err)
+			}
+			for pos, s := range strs {
+				fmt.Printf("%s: %s\n", symAddrColor("%#09x", pos), symNameColor(fmt.Sprintf("%#v", s)))
 			}
 
 			if cfstrs, err := m.GetCFStrings(); err == nil {
